@@ -9,6 +9,7 @@ dask.distributed. If someone can tell me how to fully exploit nested
 parallelism when using a dask.distributed backend, I will gladly remove this
 private module. @richford
 """
+
 import itertools
 import numbers
 import numpy as np
@@ -383,7 +384,7 @@ class SerialBaggingClassifier(BaggingClassifier):
         # Validate max_features
         if isinstance(self.max_features, numbers.Integral):
             max_features = self.max_features
-        elif isinstance(self.max_features, np.float):
+        elif isinstance(self.max_features, float):
             max_features = self.max_features * self.n_features_in_
         else:
             raise ValueError("max_features must be int or float")
@@ -897,7 +898,7 @@ class SerialBaggingRegressor(BaggingRegressor):
         # Validate max_features
         if isinstance(self.max_features, numbers.Integral):
             max_features = self.max_features
-        elif isinstance(self.max_features, np.float):  # pragma: no cover
+        elif isinstance(self.max_features, float):  # pragma: no cover
             max_features = self.max_features * self.n_features_in_
         else:  # pragma: no cover
             raise ValueError("max_features must be int or float")
